Sample test cases executed and verified for output. The output of each of the command is obtained by grepping for "relative_error"

* mpirun -np 1 ./distntf -a 2 -k 3 -d "8 8 8" -p "1 1 1" -i rand_lowrank -t 3 -e 1
=========================
Iter::0::relative_error::0.991104
Iter::1::relative_error::0.991008
Iter::2::relative_error::0.990957
Iter::3::relative_error::0.990952
Iter::4::relative_error::0.990952
Iter::5::relative_error::0.990951
Iter::6::relative_error::0.990952
Iter::7::relative_error::0.990952
Iter::8::relative_error::0.990952
Iter::9::relative_error::0.990952
Iter::10::relative_error::0.990952
Iter::11::relative_error::0.990952
Iter::12::relative_error::0.990952
Iter::13::relative_error::0.990952
Iter::14::relative_error::0.990952
Iter::15::relative_error::0.990952
Iter::16::relative_error::0.990952
Iter::17::relative_error::0.990952
Iter::18::relative_error::0.990952
Iter::19::relative_error::0.990952
Iter::20::relative_error::0.990952
Iter::21::relative_error::0.990952
Iter::22::relative_error::0.990952
Iter::23::relative_error::0.990952
Iter::24::relative_error::0.990952
Iter::25::relative_error::0.990952
Iter::26::relative_error::0.990952
Iter::27::relative_error::0.990952
Iter::28::relative_error::0.990952
Iter::29::relative_error::0.990952
=========================
* mpirun -np 1 ./distntf -a 2 -k 3 -d "8 8 8" -p "1 1 1" -i rand_lowrank -t 30 -e 1 --dimtree=1
=========================
Iter::0::relative_error::0.991104
Iter::1::relative_error::0.991008
Iter::2::relative_error::0.990957
Iter::3::relative_error::0.990952
Iter::4::relative_error::0.990952
Iter::5::relative_error::0.990951
Iter::6::relative_error::0.990952
Iter::7::relative_error::0.990952
Iter::8::relative_error::0.990952
Iter::9::relative_error::0.990952
Iter::10::relative_error::0.990952
Iter::11::relative_error::0.990952
Iter::12::relative_error::0.990952
Iter::13::relative_error::0.990952
Iter::14::relative_error::0.990952
Iter::15::relative_error::0.990952
Iter::16::relative_error::0.990952
Iter::17::relative_error::0.990952
Iter::18::relative_error::0.990952
Iter::19::relative_error::0.990952
Iter::20::relative_error::0.990952
Iter::21::relative_error::0.990952
Iter::22::relative_error::0.990952
Iter::23::relative_error::0.990952
Iter::24::relative_error::0.990952
Iter::25::relative_error::0.990952
Iter::26::relative_error::0.990952
Iter::27::relative_error::0.990952
Iter::28::relative_error::0.990952
Iter::29::relative_error::0.990952
=========================
* mpirun -np 8 ./distntf -a 2 -k 3 -d "64 64 64" -p "2 2 2" -i rand_uniform -t 30 -e 1 --dimtree=1
